# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 1.0.2rc0

No merged PRs

<!-- <END NEW CHANGELOG ENTRY> -->

## 1.0.1

([Full Changelog](https://github.com/ibm-skills-network/skills-network-authoring-jupyterlab-extension/compare/v1.0.1rc2...2bc4f1d76f61a3b85031db9528e451c8372c1404))

### Enhancements made

- feature: add v2 file library [#13](https://github.com/ibm-skills-network/skills-network-authoring-jupyterlab-extension/pull/13) ([@Ericc-Hao](https://github.com/Ericc-Hao))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ibm-skills-network/skills-network-authoring-jupyterlab-extension/graphs/contributors?from=2024-02-23&to=2024-02-26&type=c))

[@Ericc-Hao](https://github.com/search?q=repo%3Aibm-skills-network%2Fskills-network-authoring-jupyterlab-extension+involves%3AEricc-Hao+updated%3A2024-02-23..2024-02-26&type=Issues)

## 1.0.1rc5

No merged PRs

## 1.0.1rc4

No merged PRs

## 1.0.1rc2

([Full Changelog](https://github.com/ibm-skills-network/skills-network-authoring-jupyterlab-extension/compare/v1.0.0))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ibm-skills-network/skills-network-authoring-jupyterlab-extension/graphs/contributors?from=2024-02-08&to=2024-02-23&type=c))

## 1.0.0

([Full Changelog](https://github.com/ibm-skills-network/skills-network-authoring-jupyterlab-extension/compare/v0.1.1rc8...c8d6cbfee29497eb056cead1ab1979c45c80e194))

### Enhancements made

- feat: extension backend migration - jupyterlab 3.0 to 4.0 [#9](https://github.com/ibm-skills-network/skills-network-authoring-jupyterlab-extension/pull/9) ([@oliver-z-luo](https://github.com/oliver-z-luo))

### Bugs fixed

- fix: dynamically load menu bar item [#12](https://github.com/ibm-skills-network/skills-network-authoring-jupyterlab-extension/pull/12) ([@ElioDiNino](https://github.com/ElioDiNino))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ibm-skills-network/skills-network-authoring-jupyterlab-extension/graphs/contributors?from=2024-02-07&to=2024-02-08&type=c))

[@ElioDiNino](https://github.com/search?q=repo%3Aibm-skills-network%2Fskills-network-authoring-jupyterlab-extension+involves%3AElioDiNino+updated%3A2024-02-07..2024-02-08&type=Issues) | [@oliver-z-luo](https://github.com/search?q=repo%3Aibm-skills-network%2Fskills-network-authoring-jupyterlab-extension+involves%3Aoliver-z-luo+updated%3A2024-02-07..2024-02-08&type=Issues)

## 0.1.1rc9

No merged PRs

## 0.1.1rc8

([Full Changelog](https://github.com/ibm-skills-network/skills-network-authoring-jupyterlab-extension/compare/6dc4ab97f14f20c8bde3cb7a3fea700f173ef3b7...e19194dfff5c270859dc1bb1566c82630f2b3186))

### Enhancements made

- ci: create dependabot.yml and add pre-commit [#3](https://github.com/ibm-skills-network/skills-network-authoring-jupyterlab-extension/pull/3) ([@ElioDiNino](https://github.com/ElioDiNino))
- ci: workflow updates and fixes [#2](https://github.com/ibm-skills-network/skills-network-authoring-jupyterlab-extension/pull/2) ([@ElioDiNino](https://github.com/ElioDiNino))

### Other merged PRs

- ci: publishing fixes & workflow optimizations [#10](https://github.com/ibm-skills-network/skills-network-authoring-jupyterlab-extension/pull/10) ([@ElioDiNino](https://github.com/ElioDiNino))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ibm-skills-network/skills-network-authoring-jupyterlab-extension/graphs/contributors?from=2024-02-02&to=2024-02-07&type=c))

[@ElioDiNino](https://github.com/search?q=repo%3Aibm-skills-network%2Fskills-network-authoring-jupyterlab-extension+involves%3AElioDiNino+updated%3A2024-02-02..2024-02-07&type=Issues)

## 0.1.1rc7

No merged PRs

## 0.1.1rc6

No merged PRs

## 0.1.1rc5

No merged PRs

## 0.1.1rc4

No merged PRs

## 0.1.1rc3

No merged PRs

## 0.1.1rc2

No merged PRs

## 0.1.1rc1

No merged PRs

## 0.1.1rc0

No merged PRs
